@@ -60,10 +60,9 @@ def encode_value(v):
     """
     print('v-> ', v)
     # try:
-    if ';' in v or v.strip(' ').startswith('{'):
+    if (not type(v) is dict) and ';' in v or v.strip(' ').startswith('{'):
         return '{%s}' % (v.replace('}', '}}'),)
-    # except:
-    #     print('An exception occurred')
+    print('Skipped-------------------')
     return v
 
 
